@@ -142,6 +142,9 @@ class OpenRevision(RunAction):
 class ComputeRevisionHash(LaunchSessionWorker):
     _revision = flow.Parent()
 
+    def get_run_label(self):
+        return 'Compute revision hash'
+
     def allow_context(self, context):
         return False
 
@@ -187,6 +190,9 @@ class PublishFileAction(LaunchSessionWorker):
     comment = flow.SessionParam("")
     upload_after_publish = flow.BoolParam(False)
 
+    def get_run_label(self):
+        return 'Upload and save dependencies'
+
     def get_buttons(self):
         self.message.set("<h3>Publish</h3>")
 
@@ -769,6 +775,9 @@ class OpenTrackedFileAction(GenericRunAction):
     _to_open = flow.Param("")
     revision_name = flow.Param(None, RevisionsChoiceValue).ui(label="Revision")
 
+    def get_run_label(self):
+        return 'Open file'
+
     def get_buttons(self):
         if super(OpenTrackedFileAction, self).needs_dialog():
             return super(OpenTrackedFileAction, self).get_buttons()
@@ -1110,6 +1119,9 @@ class RenderBlenderPlayblastAction(OpenWithBlenderAction):
         editor='bool',
     )
 
+    def get_run_label(self):
+        return 'Render playblast'
+
     def _sequence_number_from_name(self, sequence_name):
         tmp = re.findall(r"\d+", sequence_name)
         numbers = list(map(int, tmp))
@@ -2303,6 +2315,9 @@ class ResizeTrackedFolderImages(RunAction):
     def runner_name_and_tags(self):
         return 'ImageMagick', []
     
+    def get_run_label(self):
+        return 'Resize images'
+    
     def extra_argv(self):
         in_pattern = '{}/*.png[{}]'.format(self._source_folder_path, self._resize_format)
         out_pattern = '{}/%[filename:base].png'.format(self._target_folder_path)
